import { Directive, ElementRef, forwardRef } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { Subject } from 'rxjs';
import { takeUntil } from 'rxjs/operators';
import { NgMentionsComponent } from './mentions.component';
/**
 * The MentionsAccessorDirective directive is used to indicate the input element.
 * This directive is required.
 */
var NgMentionsAccessorDirective = /** @class */ (function () {
    function NgMentionsAccessorDirective(element, host) {
        this.element = element;
        this.host = host;
        this._destroyed = new Subject();
    }
    NgMentionsAccessorDirective.prototype.ngOnInit = function () {
        var _this = this;
        this.host.valueChanges.pipe(takeUntil(this._destroyed)).subscribe(function (value) { return _this.onChange(value); });
    };
    NgMentionsAccessorDirective.prototype.ngOnDestroy = function () {
        this._destroyed.next();
        this._destroyed.complete();
    };
    NgMentionsAccessorDirective.prototype.registerOnChange = function (fn) {
        this._onChange = fn;
    };
    NgMentionsAccessorDirective.prototype.registerOnTouched = function (fn) {
        this._onTouch = fn;
    };
    NgMentionsAccessorDirective.prototype.setDisabledState = function (isDisabled) {
        this.host.disabled = isDisabled;
    };
    NgMentionsAccessorDirective.prototype.writeValue = function (value) {
        if (typeof value === 'string' || value === null) {
            this.host.value = value;
        }
    };
    NgMentionsAccessorDirective.prototype.onChange = function (value) {
        if (this._onChange) {
            this._onChange(value);
        }
    };
    NgMentionsAccessorDirective.prototype.onTouched = function () {
        if (this._onTouch) {
            this._onTouch();
        }
    };
    NgMentionsAccessorDirective.decorators = [
        { type: Directive, args: [{
                    exportAs: 'ngMentions',
                    selector: 'ng-mentions',
                    host: { '(change)': 'onChange($event)', '(touch)': 'onTouched()' },
                    providers: [{ provide: NG_VALUE_ACCESSOR, useExisting: forwardRef(function () { return NgMentionsAccessorDirective; }), multi: true }]
                },] },
    ];
    /** @nocollapse */
    NgMentionsAccessorDirective.ctorParameters = function () { return [
        { type: ElementRef },
        { type: NgMentionsComponent }
    ]; };
    return NgMentionsAccessorDirective;
}());
export { NgMentionsAccessorDirective };
//# sourceMappingURL=mentions-input.directive.js.map