import { Component, ElementRef, EventEmitter, HostBinding, TemplateRef, ViewChild, ViewEncapsulation } from '@angular/core';
import { getCaretCoordinates } from './utils';
var NgMentionsListComponent = /** @class */ (function () {
    function NgMentionsListComponent() {
        this.activeIndex = -1;
        this.itemSelected = new EventEmitter();
        this.show = false;
        this.dropUp = false;
        this._top = 0;
        this._left = 0;
    }
    Object.defineProperty(NgMentionsListComponent.prototype, "selectedItem", {
        get: function () {
            return this.activeIndex >= 0 && this.items[this.activeIndex] !== undefined ? this.items[this.activeIndex] : null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgMentionsListComponent.prototype, "top", {
        get: function () {
            return this._top + this.adjustTop + 'px';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgMentionsListComponent.prototype, "left", {
        get: function () {
            return this._left + 'px';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgMentionsListComponent.prototype, "noItems", {
        get: function () {
            return !Array.isArray(this.items) || this.items.length === 0;
        },
        enumerable: true,
        configurable: true
    });
    NgMentionsListComponent.prototype.ngOnInit = function () {
        if (!this.itemTemplate) {
            this.itemTemplate = this.defaultItemTemplate;
        }
    };
    NgMentionsListComponent.prototype.onItemClick = function (event, activeIndex, item) {
        event.preventDefault();
        this.activeIndex = activeIndex;
        this.itemSelected.emit(item);
    };
    NgMentionsListComponent.prototype.selectFirstItem = function () {
        this.activeIndex = 0;
        this.resetScroll();
    };
    NgMentionsListComponent.prototype.selectPreviousItem = function () {
        if (this.activeIndex > 0) {
            this.activeIndex--;
        }
        this.scrollToActiveItem();
    };
    NgMentionsListComponent.prototype.selectNextItem = function () {
        if (this.activeIndex < this.items.length - 1) {
            this.activeIndex++;
            this.scrollToActiveItem();
        }
    };
    NgMentionsListComponent.prototype.selectLastItem = function () {
        this.activeIndex = this.items.length > 0 ? this.items.length - 1 : 0;
        this.scrollToActiveItem();
    };
    NgMentionsListComponent.prototype.position = function () {
        var element = this.textAreaElement;
        var coords = getCaretCoordinates(element, element.selectionStart);
        this._top = coords.top;
        this._left = coords.left + element.offsetLeft;
        this.list.nativeElement.scrollTop = 0;
    };
    NgMentionsListComponent.prototype.resetScroll = function () {
        this.list.nativeElement.scrollTop = 0;
    };
    NgMentionsListComponent.prototype.transformItem = function (item) {
        return this.displayTransform(item) || item;
    };
    Object.defineProperty(NgMentionsListComponent.prototype, "adjustTop", {
        get: function () {
            var adjust = 0;
            if (!this.dropUp) {
                var computed = getComputedStyle(this.textAreaElement);
                adjust = parseInt(computed.fontSize, 10) + this.textAreaElement.offsetTop;
            }
            return adjust;
        },
        enumerable: true,
        configurable: true
    });
    NgMentionsListComponent.prototype.scrollToActiveItem = function () {
        var element = this.list.nativeElement;
        if (this.activeIndex === 0) {
            element.scrollTop = 0;
        }
        else {
            var activeElement = element.querySelector('li.active');
            if (activeElement) {
                element.scrollTop = activeElement.offsetTop;
            }
        }
    };
    NgMentionsListComponent.decorators = [
        { type: Component, args: [{
                    selector: 'mentions-list',
                    template: "\n      <ng-template #defaultItemTemplate let-item=\"item\">\n          {{transformItem(item)}}\n      </ng-template>\n      <ul #list class=\"dropdown-menu scrollable-menu\">\n          <li *ngFor=\"let item of items; let i = index\" [class.active]=\"activeIndex === i\">\n              <a href class=\"dropdown-item\" (click)=\"onItemClick($event, i, item)\">\n                  <ng-template [ngTemplateOutlet]=\"itemTemplate\"\n                               [ngTemplateOutletContext]=\"{item:item,index:i}\"></ng-template>\n              </a>\n          </li>\n      </ul>\n  ",
                    styles: [
                        'mentions-list {position: absolute;display: none;}', 'mentions-list.drop-up {transform: translateY(-100%);}',
                        'mentions-list.show {display: block;} mentions-list.no-items {display: none;}',
                        'mentions-list .scrollable-menu {display: block;height: auto;max-height:300px;overflow:auto;}',
                        'mentions-list li.active {background: #f7f7f9;}'
                    ],
                    encapsulation: ViewEncapsulation.None
                },] },
    ];
    NgMentionsListComponent.propDecorators = {
        defaultItemTemplate: [{ type: ViewChild, args: ['defaultItemTemplate',] }],
        list: [{ type: ViewChild, args: ['list',] }],
        show: [{ type: HostBinding, args: ['class.show',] }],
        dropUp: [{ type: HostBinding, args: ['class.drop-up',] }],
        top: [{ type: HostBinding, args: ['style.top',] }],
        left: [{ type: HostBinding, args: ['style.left',] }],
        noItems: [{ type: HostBinding, args: ['class.no-items',] }]
    };
    return NgMentionsListComponent;
}());
export { NgMentionsListComponent };
//# sourceMappingURL=mentions-list.component.js.map